betty.extension.nginx package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.nginx package

## Submodules

- betty.extension.nginx.artifact module
  - `generate_configuration_file()`
  - `generate_dockerfile_file()`
- betty.extension.nginx.config module
  - `NginxConfiguration`
    - `NginxConfiguration.__init__()`
    - `NginxConfiguration.dump()`
    - `NginxConfiguration.https`
    - `NginxConfiguration.load()`
    - `NginxConfiguration.update()`
    - `NginxConfiguration.www_directory_path`
- betty.extension.nginx.docker module
  - `Container`
    - `Container.__init__()`
    - `Container.ip`
    - `Container.start()`
    - `Container.stop()`
- betty.extension.nginx.serve module
  - `DockerizedNginxServer`
    - `DockerizedNginxServer.__init__()`
    - `DockerizedNginxServer.is_available()`
    - `DockerizedNginxServer.public_url`
    - `DockerizedNginxServer.start()`
    - `DockerizedNginxServer.stop()`

## Module contents

Integrate Betty with nginx.

final class betty.extension.nginx.Nginx

  Bases: `ConfigurableExtension`[`NginxConfiguration`]

  Integrate Betty with nginx (and Docker).

  classmethod assets_directory_path() → Path | None

    Return the path on disk where the extension’s assets are located.

    This may be anywhere in your Python package.

  classmethod default_configuration() → NginxConfiguration

    Get this extension’s default configuration.

  property https: bool

    Whether the nginx server should use HTTPS.

  classmethod plugin_description() → Localizable

    Get the human-readable long plugin description.

  classmethod plugin_id() → str

    Get the plugin ID.

    IDs are unique per plugin type:

    - A plugin repository MUST at most have a single plugin for any ID.

    - Different plugin repositories MAY each have a plugin with the same ID.

  classmethod plugin_label() → Localizable

    Get the human-readable short plugin label.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.

  property www_directory_path: str

    The nginx server’s public web root directory path.